##  Linking Applications to Catalog Items
When a fact sheet is linked to a catalog item, the attributes selected by the admin are automatically synced with the catalog and regularly updated.
There are three ways to link fact sheets to the catalog:
  * Bulk linking fact sheets from the inventory
  * Linking individual fact sheets from the fact sheet page
  * Linking a fact sheet during fact sheet creation


On the Last Update tab of the fact sheet page, you can check any updates made to the linked fact sheet as a result of syncing. Updates are attributed to the System user ‘reference data’ user.
![Checking Updates in the Last Update section of the Fact Sheet](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2747d9407a441014a07b92eeb61950e3_LowRes.png)
Checking Updates in the Last Update section of the Fact Sheet
